# frozen_string_literal: true

require "common_models/models/devices/input/graupner/mc20"

module CommonModels
    module Devices
        module Input
            module Graupner
                describe Mc20 do
                end
            end
        end
    end
end
